# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ZonePolicyArgs', 'ZonePolicy']

@pulumi.input_type
class ZonePolicyArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[_builtins.str],
                 destination: pulumi.Input['ZonePolicyDestinationArgs'],
                 source: pulumi.Input['ZonePolicySourceArgs'],
                 auto_allow_return_traffic: Optional[pulumi.Input[_builtins.bool]] = None,
                 connection_state_type: Optional[pulumi.Input[_builtins.str]] = None,
                 connection_states: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 index: Optional[pulumi.Input[_builtins.int]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.str]] = None,
                 logging: Optional[pulumi.Input[_builtins.bool]] = None,
                 match_ip_sec_type: Optional[pulumi.Input[_builtins.str]] = None,
                 match_opposite_protocol: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input['ZonePolicyScheduleArgs']] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ZonePolicy resource.
        :param pulumi.Input[_builtins.str] action: Determines which action to take on matching traffic. Must be one of `BLOCK`, `ALLOW`, or `REJECT`.
        :param pulumi.Input['ZonePolicyDestinationArgs'] destination: The zone matching the destination of the traffic. Optionally match on a specific destination inside the zone.
        :param pulumi.Input['ZonePolicySourceArgs'] source: The zone matching the source of the traffic. Optionally match on a specific source inside the zone.
        :param pulumi.Input[_builtins.bool] auto_allow_return_traffic: Creates a built-in policy for the opposite Zone Pair to automatically allow the return traffic. If disabled, return traffic must be manually allowed
        :param pulumi.Input[_builtins.str] connection_state_type: Optionally match on a firewall connection state such as traffic associated with an already existing connection. Valid values are `ALL`, `RESPOND_ONLY`, or `CUSTOM`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] connection_states: Connection states to match when `connection_state_type` is `CUSTOM`. Valid values include `ESTABLISHED`, `NEW`, `RELATED`, and `INVALID`.
        :param pulumi.Input[_builtins.str] description: Description of the firewall zone policy.
        :param pulumi.Input[_builtins.bool] enabled: Enable the policy
        :param pulumi.Input[_builtins.int] index: Priority index for the policy.
        :param pulumi.Input[_builtins.str] ip_version: Optionally match on only IPv4 or IPv6. Valid values are `BOTH`, `IPV4`, or `IPV6`.
        :param pulumi.Input[_builtins.bool] logging: Enable to generate syslog entries when traffic is matched.
        :param pulumi.Input[_builtins.str] match_ip_sec_type: Optionally match on traffic encrypted by IPsec. This is typically used for Ipsec Policy-Based VPNs. Valid values are `MATCH_IP_SEC` or `MATCH_NON_IP_SEC`.
        :param pulumi.Input[_builtins.bool] match_opposite_protocol: Whether to match the opposite protocol.
        :param pulumi.Input[_builtins.str] name: The name of the firewall zone policy.
        :param pulumi.Input[_builtins.str] protocol: Optionally match a specific protocol. Valid values include: `all`, `tcp_udp`, `tcp`, `udp`, etc.
        :param pulumi.Input['ZonePolicyScheduleArgs'] schedule: Enforce this policy at specific times.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "destination", destination)
        pulumi.set(__self__, "source", source)
        if auto_allow_return_traffic is not None:
            pulumi.set(__self__, "auto_allow_return_traffic", auto_allow_return_traffic)
        if connection_state_type is not None:
            pulumi.set(__self__, "connection_state_type", connection_state_type)
        if connection_states is not None:
            pulumi.set(__self__, "connection_states", connection_states)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if index is not None:
            pulumi.set(__self__, "index", index)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if logging is not None:
            pulumi.set(__self__, "logging", logging)
        if match_ip_sec_type is not None:
            pulumi.set(__self__, "match_ip_sec_type", match_ip_sec_type)
        if match_opposite_protocol is not None:
            pulumi.set(__self__, "match_opposite_protocol", match_opposite_protocol)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter
    def action(self) -> pulumi.Input[_builtins.str]:
        """
        Determines which action to take on matching traffic. Must be one of `BLOCK`, `ALLOW`, or `REJECT`.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter
    def destination(self) -> pulumi.Input['ZonePolicyDestinationArgs']:
        """
        The zone matching the destination of the traffic. Optionally match on a specific destination inside the zone.
        """
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: pulumi.Input['ZonePolicyDestinationArgs']):
        pulumi.set(self, "destination", value)

    @_builtins.property
    @pulumi.getter
    def source(self) -> pulumi.Input['ZonePolicySourceArgs']:
        """
        The zone matching the source of the traffic. Optionally match on a specific source inside the zone.
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: pulumi.Input['ZonePolicySourceArgs']):
        pulumi.set(self, "source", value)

    @_builtins.property
    @pulumi.getter(name="autoAllowReturnTraffic")
    def auto_allow_return_traffic(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Creates a built-in policy for the opposite Zone Pair to automatically allow the return traffic. If disabled, return traffic must be manually allowed
        """
        return pulumi.get(self, "auto_allow_return_traffic")

    @auto_allow_return_traffic.setter
    def auto_allow_return_traffic(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_allow_return_traffic", value)

    @_builtins.property
    @pulumi.getter(name="connectionStateType")
    def connection_state_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Optionally match on a firewall connection state such as traffic associated with an already existing connection. Valid values are `ALL`, `RESPOND_ONLY`, or `CUSTOM`.
        """
        return pulumi.get(self, "connection_state_type")

    @connection_state_type.setter
    def connection_state_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "connection_state_type", value)

    @_builtins.property
    @pulumi.getter(name="connectionStates")
    def connection_states(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Connection states to match when `connection_state_type` is `CUSTOM`. Valid values include `ESTABLISHED`, `NEW`, `RELATED`, and `INVALID`.
        """
        return pulumi.get(self, "connection_states")

    @connection_states.setter
    def connection_states(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "connection_states", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the firewall zone policy.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable the policy
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def index(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Priority index for the policy.
        """
        return pulumi.get(self, "index")

    @index.setter
    def index(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "index", value)

    @_builtins.property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Optionally match on only IPv4 or IPv6. Valid values are `BOTH`, `IPV4`, or `IPV6`.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip_version", value)

    @_builtins.property
    @pulumi.getter
    def logging(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable to generate syslog entries when traffic is matched.
        """
        return pulumi.get(self, "logging")

    @logging.setter
    def logging(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "logging", value)

    @_builtins.property
    @pulumi.getter(name="matchIpSecType")
    def match_ip_sec_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Optionally match on traffic encrypted by IPsec. This is typically used for Ipsec Policy-Based VPNs. Valid values are `MATCH_IP_SEC` or `MATCH_NON_IP_SEC`.
        """
        return pulumi.get(self, "match_ip_sec_type")

    @match_ip_sec_type.setter
    def match_ip_sec_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "match_ip_sec_type", value)

    @_builtins.property
    @pulumi.getter(name="matchOppositeProtocol")
    def match_opposite_protocol(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to match the opposite protocol.
        """
        return pulumi.get(self, "match_opposite_protocol")

    @match_opposite_protocol.setter
    def match_opposite_protocol(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "match_opposite_protocol", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the firewall zone policy.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Optionally match a specific protocol. Valid values include: `all`, `tcp_udp`, `tcp`, `udp`, etc.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['ZonePolicyScheduleArgs']]:
        """
        Enforce this policy at specific times.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['ZonePolicyScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)


@pulumi.input_type
class _ZonePolicyState:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_allow_return_traffic: Optional[pulumi.Input[_builtins.bool]] = None,
                 connection_state_type: Optional[pulumi.Input[_builtins.str]] = None,
                 connection_states: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination: Optional[pulumi.Input['ZonePolicyDestinationArgs']] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 index: Optional[pulumi.Input[_builtins.int]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.str]] = None,
                 logging: Optional[pulumi.Input[_builtins.bool]] = None,
                 match_ip_sec_type: Optional[pulumi.Input[_builtins.str]] = None,
                 match_opposite_protocol: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input['ZonePolicyScheduleArgs']] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 source: Optional[pulumi.Input['ZonePolicySourceArgs']] = None):
        """
        Input properties used for looking up and filtering ZonePolicy resources.
        :param pulumi.Input[_builtins.str] action: Determines which action to take on matching traffic. Must be one of `BLOCK`, `ALLOW`, or `REJECT`.
        :param pulumi.Input[_builtins.bool] auto_allow_return_traffic: Creates a built-in policy for the opposite Zone Pair to automatically allow the return traffic. If disabled, return traffic must be manually allowed
        :param pulumi.Input[_builtins.str] connection_state_type: Optionally match on a firewall connection state such as traffic associated with an already existing connection. Valid values are `ALL`, `RESPOND_ONLY`, or `CUSTOM`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] connection_states: Connection states to match when `connection_state_type` is `CUSTOM`. Valid values include `ESTABLISHED`, `NEW`, `RELATED`, and `INVALID`.
        :param pulumi.Input[_builtins.str] description: Description of the firewall zone policy.
        :param pulumi.Input['ZonePolicyDestinationArgs'] destination: The zone matching the destination of the traffic. Optionally match on a specific destination inside the zone.
        :param pulumi.Input[_builtins.bool] enabled: Enable the policy
        :param pulumi.Input[_builtins.int] index: Priority index for the policy.
        :param pulumi.Input[_builtins.str] ip_version: Optionally match on only IPv4 or IPv6. Valid values are `BOTH`, `IPV4`, or `IPV6`.
        :param pulumi.Input[_builtins.bool] logging: Enable to generate syslog entries when traffic is matched.
        :param pulumi.Input[_builtins.str] match_ip_sec_type: Optionally match on traffic encrypted by IPsec. This is typically used for Ipsec Policy-Based VPNs. Valid values are `MATCH_IP_SEC` or `MATCH_NON_IP_SEC`.
        :param pulumi.Input[_builtins.bool] match_opposite_protocol: Whether to match the opposite protocol.
        :param pulumi.Input[_builtins.str] name: The name of the firewall zone policy.
        :param pulumi.Input[_builtins.str] protocol: Optionally match a specific protocol. Valid values include: `all`, `tcp_udp`, `tcp`, `udp`, etc.
        :param pulumi.Input['ZonePolicyScheduleArgs'] schedule: Enforce this policy at specific times.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input['ZonePolicySourceArgs'] source: The zone matching the source of the traffic. Optionally match on a specific source inside the zone.
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if auto_allow_return_traffic is not None:
            pulumi.set(__self__, "auto_allow_return_traffic", auto_allow_return_traffic)
        if connection_state_type is not None:
            pulumi.set(__self__, "connection_state_type", connection_state_type)
        if connection_states is not None:
            pulumi.set(__self__, "connection_states", connection_states)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination is not None:
            pulumi.set(__self__, "destination", destination)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if index is not None:
            pulumi.set(__self__, "index", index)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if logging is not None:
            pulumi.set(__self__, "logging", logging)
        if match_ip_sec_type is not None:
            pulumi.set(__self__, "match_ip_sec_type", match_ip_sec_type)
        if match_opposite_protocol is not None:
            pulumi.set(__self__, "match_opposite_protocol", match_opposite_protocol)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if source is not None:
            pulumi.set(__self__, "source", source)

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines which action to take on matching traffic. Must be one of `BLOCK`, `ALLOW`, or `REJECT`.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter(name="autoAllowReturnTraffic")
    def auto_allow_return_traffic(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Creates a built-in policy for the opposite Zone Pair to automatically allow the return traffic. If disabled, return traffic must be manually allowed
        """
        return pulumi.get(self, "auto_allow_return_traffic")

    @auto_allow_return_traffic.setter
    def auto_allow_return_traffic(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_allow_return_traffic", value)

    @_builtins.property
    @pulumi.getter(name="connectionStateType")
    def connection_state_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Optionally match on a firewall connection state such as traffic associated with an already existing connection. Valid values are `ALL`, `RESPOND_ONLY`, or `CUSTOM`.
        """
        return pulumi.get(self, "connection_state_type")

    @connection_state_type.setter
    def connection_state_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "connection_state_type", value)

    @_builtins.property
    @pulumi.getter(name="connectionStates")
    def connection_states(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Connection states to match when `connection_state_type` is `CUSTOM`. Valid values include `ESTABLISHED`, `NEW`, `RELATED`, and `INVALID`.
        """
        return pulumi.get(self, "connection_states")

    @connection_states.setter
    def connection_states(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "connection_states", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the firewall zone policy.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def destination(self) -> Optional[pulumi.Input['ZonePolicyDestinationArgs']]:
        """
        The zone matching the destination of the traffic. Optionally match on a specific destination inside the zone.
        """
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: Optional[pulumi.Input['ZonePolicyDestinationArgs']]):
        pulumi.set(self, "destination", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable the policy
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def index(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Priority index for the policy.
        """
        return pulumi.get(self, "index")

    @index.setter
    def index(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "index", value)

    @_builtins.property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Optionally match on only IPv4 or IPv6. Valid values are `BOTH`, `IPV4`, or `IPV6`.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip_version", value)

    @_builtins.property
    @pulumi.getter
    def logging(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable to generate syslog entries when traffic is matched.
        """
        return pulumi.get(self, "logging")

    @logging.setter
    def logging(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "logging", value)

    @_builtins.property
    @pulumi.getter(name="matchIpSecType")
    def match_ip_sec_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Optionally match on traffic encrypted by IPsec. This is typically used for Ipsec Policy-Based VPNs. Valid values are `MATCH_IP_SEC` or `MATCH_NON_IP_SEC`.
        """
        return pulumi.get(self, "match_ip_sec_type")

    @match_ip_sec_type.setter
    def match_ip_sec_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "match_ip_sec_type", value)

    @_builtins.property
    @pulumi.getter(name="matchOppositeProtocol")
    def match_opposite_protocol(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to match the opposite protocol.
        """
        return pulumi.get(self, "match_opposite_protocol")

    @match_opposite_protocol.setter
    def match_opposite_protocol(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "match_opposite_protocol", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the firewall zone policy.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Optionally match a specific protocol. Valid values include: `all`, `tcp_udp`, `tcp`, `udp`, etc.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['ZonePolicyScheduleArgs']]:
        """
        Enforce this policy at specific times.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['ZonePolicyScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input['ZonePolicySourceArgs']]:
        """
        The zone matching the source of the traffic. Optionally match on a specific source inside the zone.
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input['ZonePolicySourceArgs']]):
        pulumi.set(self, "source", value)


@pulumi.type_token("unifi:firewall/zonePolicy:ZonePolicy")
class ZonePolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_allow_return_traffic: Optional[pulumi.Input[_builtins.bool]] = None,
                 connection_state_type: Optional[pulumi.Input[_builtins.str]] = None,
                 connection_states: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination: Optional[pulumi.Input[Union['ZonePolicyDestinationArgs', 'ZonePolicyDestinationArgsDict']]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 index: Optional[pulumi.Input[_builtins.int]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.str]] = None,
                 logging: Optional[pulumi.Input[_builtins.bool]] = None,
                 match_ip_sec_type: Optional[pulumi.Input[_builtins.str]] = None,
                 match_opposite_protocol: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input[Union['ZonePolicyScheduleArgs', 'ZonePolicyScheduleArgsDict']]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 source: Optional[pulumi.Input[Union['ZonePolicySourceArgs', 'ZonePolicySourceArgsDict']]] = None,
                 __props__=None):
        """
        The `firewall.ZonePolicy` resource manages firewall policies between zones in the UniFi controller. This resource allows you to create, update, and delete policies that define allowed or blocked traffic between zones.

        !> This is experimental feature, that requires UniFi OS 9.0.0 or later and Zone Based Firewall feature enabled. Check [official documentation](https://help.ui.com/hc/en-us/articles/28223082254743-Migrating-to-Zone-Based-Firewalls-in-UniFi) how to migate to Zone-Based firewalls.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        network = unifi.Network("network",
            name="my-network",
            purpose="corporate",
            subnet="10.0.10.0/24",
            vlan_id=400)
        src = unifi.firewall.Zone("src",
            name="my-source-zone",
            networks=[network.id])
        dst = unifi.firewall.Zone("dst", name="my-destination-zone")
        # Allow TCP/UDP traffic from any ip and port other than 192.168.1.1 and 443 in `src` zone to `dst` zone
        policy = unifi.firewall.ZonePolicy("policy",
            name="my-zone-policy",
            action="ALLOW",
            protocol="tcp_udp",
            source={
                "zone_id": src.id,
                "ips": ["192.168.1.1"],
                "port": 443,
                "match_opposite_ips": True,
                "match_opposite_ports": True,
            },
            destination={
                "zone_id": dst.id,
            },
            schedule={
                "mode": "EVERY_DAY",
                "time_all_day": False,
                "time_from": "08:00",
                "time_to": "17:00",
            })
        web_ports = unifi.firewall.Group("web-ports",
            name="web-apps",
            type="port-group",
            members=[
                "80",
                "443",
            ])
        # Block TCP/UDP traffic from any ip and port in `src` zone to `dst` zone ports 80 and 443 defined in port group
        policy2 = unifi.firewall.ZonePolicy("policy2",
            name="my-policy-2",
            action="BLOCK",
            protocol="tcp_udp",
            source={
                "zone_id": src.id,
            },
            destination={
                "zone_id": dst.id,
                "port_group_id": web_ports.id,
            })
        ```

        ## Import

        import from provider configured site

        ```sh
        $ pulumi import unifi:firewall/zonePolicy:ZonePolicy mynetwork 5dc28e5e9106d105bdc87217
        ```

        import from another site

        ```sh
        $ pulumi import unifi:firewall/zonePolicy:ZonePolicy mynetwork zone:5dc28e5e9106d105bdc87217
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] action: Determines which action to take on matching traffic. Must be one of `BLOCK`, `ALLOW`, or `REJECT`.
        :param pulumi.Input[_builtins.bool] auto_allow_return_traffic: Creates a built-in policy for the opposite Zone Pair to automatically allow the return traffic. If disabled, return traffic must be manually allowed
        :param pulumi.Input[_builtins.str] connection_state_type: Optionally match on a firewall connection state such as traffic associated with an already existing connection. Valid values are `ALL`, `RESPOND_ONLY`, or `CUSTOM`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] connection_states: Connection states to match when `connection_state_type` is `CUSTOM`. Valid values include `ESTABLISHED`, `NEW`, `RELATED`, and `INVALID`.
        :param pulumi.Input[_builtins.str] description: Description of the firewall zone policy.
        :param pulumi.Input[Union['ZonePolicyDestinationArgs', 'ZonePolicyDestinationArgsDict']] destination: The zone matching the destination of the traffic. Optionally match on a specific destination inside the zone.
        :param pulumi.Input[_builtins.bool] enabled: Enable the policy
        :param pulumi.Input[_builtins.int] index: Priority index for the policy.
        :param pulumi.Input[_builtins.str] ip_version: Optionally match on only IPv4 or IPv6. Valid values are `BOTH`, `IPV4`, or `IPV6`.
        :param pulumi.Input[_builtins.bool] logging: Enable to generate syslog entries when traffic is matched.
        :param pulumi.Input[_builtins.str] match_ip_sec_type: Optionally match on traffic encrypted by IPsec. This is typically used for Ipsec Policy-Based VPNs. Valid values are `MATCH_IP_SEC` or `MATCH_NON_IP_SEC`.
        :param pulumi.Input[_builtins.bool] match_opposite_protocol: Whether to match the opposite protocol.
        :param pulumi.Input[_builtins.str] name: The name of the firewall zone policy.
        :param pulumi.Input[_builtins.str] protocol: Optionally match a specific protocol. Valid values include: `all`, `tcp_udp`, `tcp`, `udp`, etc.
        :param pulumi.Input[Union['ZonePolicyScheduleArgs', 'ZonePolicyScheduleArgsDict']] schedule: Enforce this policy at specific times.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input[Union['ZonePolicySourceArgs', 'ZonePolicySourceArgsDict']] source: The zone matching the source of the traffic. Optionally match on a specific source inside the zone.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ZonePolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `firewall.ZonePolicy` resource manages firewall policies between zones in the UniFi controller. This resource allows you to create, update, and delete policies that define allowed or blocked traffic between zones.

        !> This is experimental feature, that requires UniFi OS 9.0.0 or later and Zone Based Firewall feature enabled. Check [official documentation](https://help.ui.com/hc/en-us/articles/28223082254743-Migrating-to-Zone-Based-Firewalls-in-UniFi) how to migate to Zone-Based firewalls.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        network = unifi.Network("network",
            name="my-network",
            purpose="corporate",
            subnet="10.0.10.0/24",
            vlan_id=400)
        src = unifi.firewall.Zone("src",
            name="my-source-zone",
            networks=[network.id])
        dst = unifi.firewall.Zone("dst", name="my-destination-zone")
        # Allow TCP/UDP traffic from any ip and port other than 192.168.1.1 and 443 in `src` zone to `dst` zone
        policy = unifi.firewall.ZonePolicy("policy",
            name="my-zone-policy",
            action="ALLOW",
            protocol="tcp_udp",
            source={
                "zone_id": src.id,
                "ips": ["192.168.1.1"],
                "port": 443,
                "match_opposite_ips": True,
                "match_opposite_ports": True,
            },
            destination={
                "zone_id": dst.id,
            },
            schedule={
                "mode": "EVERY_DAY",
                "time_all_day": False,
                "time_from": "08:00",
                "time_to": "17:00",
            })
        web_ports = unifi.firewall.Group("web-ports",
            name="web-apps",
            type="port-group",
            members=[
                "80",
                "443",
            ])
        # Block TCP/UDP traffic from any ip and port in `src` zone to `dst` zone ports 80 and 443 defined in port group
        policy2 = unifi.firewall.ZonePolicy("policy2",
            name="my-policy-2",
            action="BLOCK",
            protocol="tcp_udp",
            source={
                "zone_id": src.id,
            },
            destination={
                "zone_id": dst.id,
                "port_group_id": web_ports.id,
            })
        ```

        ## Import

        import from provider configured site

        ```sh
        $ pulumi import unifi:firewall/zonePolicy:ZonePolicy mynetwork 5dc28e5e9106d105bdc87217
        ```

        import from another site

        ```sh
        $ pulumi import unifi:firewall/zonePolicy:ZonePolicy mynetwork zone:5dc28e5e9106d105bdc87217
        ```

        :param str resource_name: The name of the resource.
        :param ZonePolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ZonePolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 auto_allow_return_traffic: Optional[pulumi.Input[_builtins.bool]] = None,
                 connection_state_type: Optional[pulumi.Input[_builtins.str]] = None,
                 connection_states: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination: Optional[pulumi.Input[Union['ZonePolicyDestinationArgs', 'ZonePolicyDestinationArgsDict']]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 index: Optional[pulumi.Input[_builtins.int]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.str]] = None,
                 logging: Optional[pulumi.Input[_builtins.bool]] = None,
                 match_ip_sec_type: Optional[pulumi.Input[_builtins.str]] = None,
                 match_opposite_protocol: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input[Union['ZonePolicyScheduleArgs', 'ZonePolicyScheduleArgsDict']]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 source: Optional[pulumi.Input[Union['ZonePolicySourceArgs', 'ZonePolicySourceArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ZonePolicyArgs.__new__(ZonePolicyArgs)

            if action is None and not opts.urn:
                raise TypeError("Missing required property 'action'")
            __props__.__dict__["action"] = action
            __props__.__dict__["auto_allow_return_traffic"] = auto_allow_return_traffic
            __props__.__dict__["connection_state_type"] = connection_state_type
            __props__.__dict__["connection_states"] = connection_states
            __props__.__dict__["description"] = description
            if destination is None and not opts.urn:
                raise TypeError("Missing required property 'destination'")
            __props__.__dict__["destination"] = destination
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["index"] = index
            __props__.__dict__["ip_version"] = ip_version
            __props__.__dict__["logging"] = logging
            __props__.__dict__["match_ip_sec_type"] = match_ip_sec_type
            __props__.__dict__["match_opposite_protocol"] = match_opposite_protocol
            __props__.__dict__["name"] = name
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["schedule"] = schedule
            __props__.__dict__["site"] = site
            if source is None and not opts.urn:
                raise TypeError("Missing required property 'source'")
            __props__.__dict__["source"] = source
        super(ZonePolicy, __self__).__init__(
            'unifi:firewall/zonePolicy:ZonePolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[_builtins.str]] = None,
            auto_allow_return_traffic: Optional[pulumi.Input[_builtins.bool]] = None,
            connection_state_type: Optional[pulumi.Input[_builtins.str]] = None,
            connection_states: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            destination: Optional[pulumi.Input[Union['ZonePolicyDestinationArgs', 'ZonePolicyDestinationArgsDict']]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            index: Optional[pulumi.Input[_builtins.int]] = None,
            ip_version: Optional[pulumi.Input[_builtins.str]] = None,
            logging: Optional[pulumi.Input[_builtins.bool]] = None,
            match_ip_sec_type: Optional[pulumi.Input[_builtins.str]] = None,
            match_opposite_protocol: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            protocol: Optional[pulumi.Input[_builtins.str]] = None,
            schedule: Optional[pulumi.Input[Union['ZonePolicyScheduleArgs', 'ZonePolicyScheduleArgsDict']]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None,
            source: Optional[pulumi.Input[Union['ZonePolicySourceArgs', 'ZonePolicySourceArgsDict']]] = None) -> 'ZonePolicy':
        """
        Get an existing ZonePolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] action: Determines which action to take on matching traffic. Must be one of `BLOCK`, `ALLOW`, or `REJECT`.
        :param pulumi.Input[_builtins.bool] auto_allow_return_traffic: Creates a built-in policy for the opposite Zone Pair to automatically allow the return traffic. If disabled, return traffic must be manually allowed
        :param pulumi.Input[_builtins.str] connection_state_type: Optionally match on a firewall connection state such as traffic associated with an already existing connection. Valid values are `ALL`, `RESPOND_ONLY`, or `CUSTOM`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] connection_states: Connection states to match when `connection_state_type` is `CUSTOM`. Valid values include `ESTABLISHED`, `NEW`, `RELATED`, and `INVALID`.
        :param pulumi.Input[_builtins.str] description: Description of the firewall zone policy.
        :param pulumi.Input[Union['ZonePolicyDestinationArgs', 'ZonePolicyDestinationArgsDict']] destination: The zone matching the destination of the traffic. Optionally match on a specific destination inside the zone.
        :param pulumi.Input[_builtins.bool] enabled: Enable the policy
        :param pulumi.Input[_builtins.int] index: Priority index for the policy.
        :param pulumi.Input[_builtins.str] ip_version: Optionally match on only IPv4 or IPv6. Valid values are `BOTH`, `IPV4`, or `IPV6`.
        :param pulumi.Input[_builtins.bool] logging: Enable to generate syslog entries when traffic is matched.
        :param pulumi.Input[_builtins.str] match_ip_sec_type: Optionally match on traffic encrypted by IPsec. This is typically used for Ipsec Policy-Based VPNs. Valid values are `MATCH_IP_SEC` or `MATCH_NON_IP_SEC`.
        :param pulumi.Input[_builtins.bool] match_opposite_protocol: Whether to match the opposite protocol.
        :param pulumi.Input[_builtins.str] name: The name of the firewall zone policy.
        :param pulumi.Input[_builtins.str] protocol: Optionally match a specific protocol. Valid values include: `all`, `tcp_udp`, `tcp`, `udp`, etc.
        :param pulumi.Input[Union['ZonePolicyScheduleArgs', 'ZonePolicyScheduleArgsDict']] schedule: Enforce this policy at specific times.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input[Union['ZonePolicySourceArgs', 'ZonePolicySourceArgsDict']] source: The zone matching the source of the traffic. Optionally match on a specific source inside the zone.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ZonePolicyState.__new__(_ZonePolicyState)

        __props__.__dict__["action"] = action
        __props__.__dict__["auto_allow_return_traffic"] = auto_allow_return_traffic
        __props__.__dict__["connection_state_type"] = connection_state_type
        __props__.__dict__["connection_states"] = connection_states
        __props__.__dict__["description"] = description
        __props__.__dict__["destination"] = destination
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["index"] = index
        __props__.__dict__["ip_version"] = ip_version
        __props__.__dict__["logging"] = logging
        __props__.__dict__["match_ip_sec_type"] = match_ip_sec_type
        __props__.__dict__["match_opposite_protocol"] = match_opposite_protocol
        __props__.__dict__["name"] = name
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["schedule"] = schedule
        __props__.__dict__["site"] = site
        __props__.__dict__["source"] = source
        return ZonePolicy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def action(self) -> pulumi.Output[_builtins.str]:
        """
        Determines which action to take on matching traffic. Must be one of `BLOCK`, `ALLOW`, or `REJECT`.
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter(name="autoAllowReturnTraffic")
    def auto_allow_return_traffic(self) -> pulumi.Output[_builtins.bool]:
        """
        Creates a built-in policy for the opposite Zone Pair to automatically allow the return traffic. If disabled, return traffic must be manually allowed
        """
        return pulumi.get(self, "auto_allow_return_traffic")

    @_builtins.property
    @pulumi.getter(name="connectionStateType")
    def connection_state_type(self) -> pulumi.Output[_builtins.str]:
        """
        Optionally match on a firewall connection state such as traffic associated with an already existing connection. Valid values are `ALL`, `RESPOND_ONLY`, or `CUSTOM`.
        """
        return pulumi.get(self, "connection_state_type")

    @_builtins.property
    @pulumi.getter(name="connectionStates")
    def connection_states(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Connection states to match when `connection_state_type` is `CUSTOM`. Valid values include `ESTABLISHED`, `NEW`, `RELATED`, and `INVALID`.
        """
        return pulumi.get(self, "connection_states")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the firewall zone policy.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def destination(self) -> pulumi.Output['outputs.ZonePolicyDestination']:
        """
        The zone matching the destination of the traffic. Optionally match on a specific destination inside the zone.
        """
        return pulumi.get(self, "destination")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable the policy
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def index(self) -> pulumi.Output[_builtins.int]:
        """
        Priority index for the policy.
        """
        return pulumi.get(self, "index")

    @_builtins.property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Output[_builtins.str]:
        """
        Optionally match on only IPv4 or IPv6. Valid values are `BOTH`, `IPV4`, or `IPV6`.
        """
        return pulumi.get(self, "ip_version")

    @_builtins.property
    @pulumi.getter
    def logging(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable to generate syslog entries when traffic is matched.
        """
        return pulumi.get(self, "logging")

    @_builtins.property
    @pulumi.getter(name="matchIpSecType")
    def match_ip_sec_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Optionally match on traffic encrypted by IPsec. This is typically used for Ipsec Policy-Based VPNs. Valid values are `MATCH_IP_SEC` or `MATCH_NON_IP_SEC`.
        """
        return pulumi.get(self, "match_ip_sec_type")

    @_builtins.property
    @pulumi.getter(name="matchOppositeProtocol")
    def match_opposite_protocol(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to match the opposite protocol.
        """
        return pulumi.get(self, "match_opposite_protocol")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the firewall zone policy.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[_builtins.str]:
        """
        Optionally match a specific protocol. Valid values include: `all`, `tcp_udp`, `tcp`, `udp`, etc.
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> pulumi.Output['outputs.ZonePolicySchedule']:
        """
        Enforce this policy at specific times.
        """
        return pulumi.get(self, "schedule")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @_builtins.property
    @pulumi.getter
    def source(self) -> pulumi.Output['outputs.ZonePolicySource']:
        """
        The zone matching the source of the traffic. Optionally match on a specific source inside the zone.
        """
        return pulumi.get(self, "source")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetRecordsResultResult',
]

@pulumi.output_type
class GetRecordsResultResult(dict):
    def __init__(__self__, *,
                 enabled: _builtins.bool,
                 id: _builtins.str,
                 name: _builtins.str,
                 port: _builtins.int,
                 priority: _builtins.int,
                 record: _builtins.str,
                 site: _builtins.str,
                 ttl: _builtins.int,
                 type: _builtins.str,
                 weight: _builtins.int):
        """
        :param _builtins.bool enabled: Whether the DNS record is enabled.
        :param _builtins.str id: The unique identifier of this resource.
        :param _builtins.str name: DNS record name.
        :param _builtins.int port: The port of the DNS record.
        :param _builtins.int priority: Priority of the DNS records. Present only for MX and SRV records; unused by other record types.
        :param _builtins.str record: DNS record content.
        :param _builtins.str site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param _builtins.int ttl: Time To Live (TTL) of the DNS record in seconds. Setting to 0 means 'automatic'.
        :param _builtins.str type: The type of the DNS record.
        :param _builtins.int weight: A numeric value indicating the relative weight of the record.
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "priority", priority)
        pulumi.set(__self__, "record", record)
        pulumi.set(__self__, "site", site)
        pulumi.set(__self__, "ttl", ttl)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "weight", weight)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> _builtins.bool:
        """
        Whether the DNS record is enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of this resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        DNS record name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        The port of the DNS record.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> _builtins.int:
        """
        Priority of the DNS records. Present only for MX and SRV records; unused by other record types.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter
    def record(self) -> _builtins.str:
        """
        DNS record content.
        """
        return pulumi.get(self, "record")

    @_builtins.property
    @pulumi.getter
    def site(self) -> _builtins.str:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> _builtins.int:
        """
        Time To Live (TTL) of the DNS record in seconds. Setting to 0 means 'automatic'.
        """
        return pulumi.get(self, "ttl")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of the DNS record.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def weight(self) -> _builtins.int:
        """
        A numeric value indicating the relative weight of the record.
        """
        return pulumi.get(self, "weight")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 mac: pulumi.Input[_builtins.str],
                 allow_existing: Optional[pulumi.Input[_builtins.bool]] = None,
                 blocked: Optional[pulumi.Input[_builtins.bool]] = None,
                 dev_id_override: Optional[pulumi.Input[_builtins.int]] = None,
                 fixed_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 local_dns_record: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 note: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_forget_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_group_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[_builtins.str] mac: The MAC address of the device/client. This is used as the unique identifier and cannot be changed after creation. Must be a valid MAC address format (e.g., '00:11:22:33:44:55'). MAC addresses are case-insensitive.
        :param pulumi.Input[_builtins.bool] allow_existing: Allow this resource to take over management of an existing user in the UniFi controller. When true:
                 * The resource can manage users that were automatically created when devices connected
                 * Existing settings will be overwritten with the values specified in this resource
                 * If false, attempting to manage an existing user will result in an error
               
               Use with caution as it can modify settings for devices already connected to your network.
        :param pulumi.Input[_builtins.bool] blocked: When true, this client will be blocked from accessing the network. Useful for temporarily or permanently restricting network access for specific devices.
        :param pulumi.Input[_builtins.int] dev_id_override: Override the device fingerprint.
        :param pulumi.Input[_builtins.str] fixed_ip: A static IPv4 address to assign to this client. Ensure this IP is within the client's network range and not already assigned to another device.
        :param pulumi.Input[_builtins.str] local_dns_record: A local DNS hostname for this client. When set, other devices on the network can resolve this name to the client's IP address (e.g., 'printer.local', 'nas.home.arpa'). Such DNS record is automatically added to controller's DNS records.
        :param pulumi.Input[_builtins.str] name: A friendly name for the device/client. This helps identify the device in the UniFi interface (eg. 'Living Room TV', 'John's Laptop').
        :param pulumi.Input[_builtins.str] network_id: The ID of the network this client should be associated with. This is particularly important when using VLANs or multiple networks.
        :param pulumi.Input[_builtins.str] note: Additional information about the client that you want to record (e.g., 'Company asset tag #12345', 'Guest device - expires 2024-03-01').
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this user should be managed. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.bool] skip_forget_on_destroy: When false (default), the client will be 'forgotten' by the controller when this resource is destroyed. Set to true to keep the client's history in the controller after the resource is removed from Terraform.
        :param pulumi.Input[_builtins.str] user_group_id: The ID of the user group this client belongs to. User groups can be used to apply common settings and restrictions to multiple clients.
        """
        pulumi.set(__self__, "mac", mac)
        if allow_existing is not None:
            pulumi.set(__self__, "allow_existing", allow_existing)
        if blocked is not None:
            pulumi.set(__self__, "blocked", blocked)
        if dev_id_override is not None:
            pulumi.set(__self__, "dev_id_override", dev_id_override)
        if fixed_ip is not None:
            pulumi.set(__self__, "fixed_ip", fixed_ip)
        if local_dns_record is not None:
            pulumi.set(__self__, "local_dns_record", local_dns_record)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_id is not None:
            pulumi.set(__self__, "network_id", network_id)
        if note is not None:
            pulumi.set(__self__, "note", note)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if skip_forget_on_destroy is not None:
            pulumi.set(__self__, "skip_forget_on_destroy", skip_forget_on_destroy)
        if user_group_id is not None:
            pulumi.set(__self__, "user_group_id", user_group_id)

    @_builtins.property
    @pulumi.getter
    def mac(self) -> pulumi.Input[_builtins.str]:
        """
        The MAC address of the device/client. This is used as the unique identifier and cannot be changed after creation. Must be a valid MAC address format (e.g., '00:11:22:33:44:55'). MAC addresses are case-insensitive.
        """
        return pulumi.get(self, "mac")

    @mac.setter
    def mac(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "mac", value)

    @_builtins.property
    @pulumi.getter(name="allowExisting")
    def allow_existing(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow this resource to take over management of an existing user in the UniFi controller. When true:
          * The resource can manage users that were automatically created when devices connected
          * Existing settings will be overwritten with the values specified in this resource
          * If false, attempting to manage an existing user will result in an error

        Use with caution as it can modify settings for devices already connected to your network.
        """
        return pulumi.get(self, "allow_existing")

    @allow_existing.setter
    def allow_existing(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_existing", value)

    @_builtins.property
    @pulumi.getter
    def blocked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When true, this client will be blocked from accessing the network. Useful for temporarily or permanently restricting network access for specific devices.
        """
        return pulumi.get(self, "blocked")

    @blocked.setter
    def blocked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "blocked", value)

    @_builtins.property
    @pulumi.getter(name="devIdOverride")
    def dev_id_override(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Override the device fingerprint.
        """
        return pulumi.get(self, "dev_id_override")

    @dev_id_override.setter
    def dev_id_override(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "dev_id_override", value)

    @_builtins.property
    @pulumi.getter(name="fixedIp")
    def fixed_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A static IPv4 address to assign to this client. Ensure this IP is within the client's network range and not already assigned to another device.
        """
        return pulumi.get(self, "fixed_ip")

    @fixed_ip.setter
    def fixed_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fixed_ip", value)

    @_builtins.property
    @pulumi.getter(name="localDnsRecord")
    def local_dns_record(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A local DNS hostname for this client. When set, other devices on the network can resolve this name to the client's IP address (e.g., 'printer.local', 'nas.home.arpa'). Such DNS record is automatically added to controller's DNS records.
        """
        return pulumi.get(self, "local_dns_record")

    @local_dns_record.setter
    def local_dns_record(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "local_dns_record", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A friendly name for the device/client. This helps identify the device in the UniFi interface (eg. 'Living Room TV', 'John's Laptop').
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="networkId")
    def network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the network this client should be associated with. This is particularly important when using VLANs or multiple networks.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "network_id", value)

    @_builtins.property
    @pulumi.getter
    def note(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional information about the client that you want to record (e.g., 'Company asset tag #12345', 'Guest device - expires 2024-03-01').
        """
        return pulumi.get(self, "note")

    @note.setter
    def note(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "note", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this user should be managed. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter(name="skipForgetOnDestroy")
    def skip_forget_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When false (default), the client will be 'forgotten' by the controller when this resource is destroyed. Set to true to keep the client's history in the controller after the resource is removed from Terraform.
        """
        return pulumi.get(self, "skip_forget_on_destroy")

    @skip_forget_on_destroy.setter
    def skip_forget_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_forget_on_destroy", value)

    @_builtins.property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the user group this client belongs to. User groups can be used to apply common settings and restrictions to multiple clients.
        """
        return pulumi.get(self, "user_group_id")

    @user_group_id.setter
    def user_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_group_id", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 allow_existing: Optional[pulumi.Input[_builtins.bool]] = None,
                 blocked: Optional[pulumi.Input[_builtins.bool]] = None,
                 dev_id_override: Optional[pulumi.Input[_builtins.int]] = None,
                 fixed_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 hostname: Optional[pulumi.Input[_builtins.str]] = None,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 local_dns_record: Optional[pulumi.Input[_builtins.str]] = None,
                 mac: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 note: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_forget_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_group_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[_builtins.bool] allow_existing: Allow this resource to take over management of an existing user in the UniFi controller. When true:
                 * The resource can manage users that were automatically created when devices connected
                 * Existing settings will be overwritten with the values specified in this resource
                 * If false, attempting to manage an existing user will result in an error
               
               Use with caution as it can modify settings for devices already connected to your network.
        :param pulumi.Input[_builtins.bool] blocked: When true, this client will be blocked from accessing the network. Useful for temporarily or permanently restricting network access for specific devices.
        :param pulumi.Input[_builtins.int] dev_id_override: Override the device fingerprint.
        :param pulumi.Input[_builtins.str] fixed_ip: A static IPv4 address to assign to this client. Ensure this IP is within the client's network range and not already assigned to another device.
        :param pulumi.Input[_builtins.str] hostname: The hostname of the user.
        :param pulumi.Input[_builtins.str] ip: The IP address of the user.
        :param pulumi.Input[_builtins.str] local_dns_record: A local DNS hostname for this client. When set, other devices on the network can resolve this name to the client's IP address (e.g., 'printer.local', 'nas.home.arpa'). Such DNS record is automatically added to controller's DNS records.
        :param pulumi.Input[_builtins.str] mac: The MAC address of the device/client. This is used as the unique identifier and cannot be changed after creation. Must be a valid MAC address format (e.g., '00:11:22:33:44:55'). MAC addresses are case-insensitive.
        :param pulumi.Input[_builtins.str] name: A friendly name for the device/client. This helps identify the device in the UniFi interface (eg. 'Living Room TV', 'John's Laptop').
        :param pulumi.Input[_builtins.str] network_id: The ID of the network this client should be associated with. This is particularly important when using VLANs or multiple networks.
        :param pulumi.Input[_builtins.str] note: Additional information about the client that you want to record (e.g., 'Company asset tag #12345', 'Guest device - expires 2024-03-01').
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this user should be managed. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.bool] skip_forget_on_destroy: When false (default), the client will be 'forgotten' by the controller when this resource is destroyed. Set to true to keep the client's history in the controller after the resource is removed from Terraform.
        :param pulumi.Input[_builtins.str] user_group_id: The ID of the user group this client belongs to. User groups can be used to apply common settings and restrictions to multiple clients.
        """
        if allow_existing is not None:
            pulumi.set(__self__, "allow_existing", allow_existing)
        if blocked is not None:
            pulumi.set(__self__, "blocked", blocked)
        if dev_id_override is not None:
            pulumi.set(__self__, "dev_id_override", dev_id_override)
        if fixed_ip is not None:
            pulumi.set(__self__, "fixed_ip", fixed_ip)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if local_dns_record is not None:
            pulumi.set(__self__, "local_dns_record", local_dns_record)
        if mac is not None:
            pulumi.set(__self__, "mac", mac)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_id is not None:
            pulumi.set(__self__, "network_id", network_id)
        if note is not None:
            pulumi.set(__self__, "note", note)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if skip_forget_on_destroy is not None:
            pulumi.set(__self__, "skip_forget_on_destroy", skip_forget_on_destroy)
        if user_group_id is not None:
            pulumi.set(__self__, "user_group_id", user_group_id)

    @_builtins.property
    @pulumi.getter(name="allowExisting")
    def allow_existing(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Allow this resource to take over management of an existing user in the UniFi controller. When true:
          * The resource can manage users that were automatically created when devices connected
          * Existing settings will be overwritten with the values specified in this resource
          * If false, attempting to manage an existing user will result in an error

        Use with caution as it can modify settings for devices already connected to your network.
        """
        return pulumi.get(self, "allow_existing")

    @allow_existing.setter
    def allow_existing(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "allow_existing", value)

    @_builtins.property
    @pulumi.getter
    def blocked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When true, this client will be blocked from accessing the network. Useful for temporarily or permanently restricting network access for specific devices.
        """
        return pulumi.get(self, "blocked")

    @blocked.setter
    def blocked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "blocked", value)

    @_builtins.property
    @pulumi.getter(name="devIdOverride")
    def dev_id_override(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Override the device fingerprint.
        """
        return pulumi.get(self, "dev_id_override")

    @dev_id_override.setter
    def dev_id_override(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "dev_id_override", value)

    @_builtins.property
    @pulumi.getter(name="fixedIp")
    def fixed_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A static IPv4 address to assign to this client. Ensure this IP is within the client's network range and not already assigned to another device.
        """
        return pulumi.get(self, "fixed_ip")

    @fixed_ip.setter
    def fixed_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fixed_ip", value)

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hostname of the user.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hostname", value)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IP address of the user.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter(name="localDnsRecord")
    def local_dns_record(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A local DNS hostname for this client. When set, other devices on the network can resolve this name to the client's IP address (e.g., 'printer.local', 'nas.home.arpa'). Such DNS record is automatically added to controller's DNS records.
        """
        return pulumi.get(self, "local_dns_record")

    @local_dns_record.setter
    def local_dns_record(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "local_dns_record", value)

    @_builtins.property
    @pulumi.getter
    def mac(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The MAC address of the device/client. This is used as the unique identifier and cannot be changed after creation. Must be a valid MAC address format (e.g., '00:11:22:33:44:55'). MAC addresses are case-insensitive.
        """
        return pulumi.get(self, "mac")

    @mac.setter
    def mac(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mac", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A friendly name for the device/client. This helps identify the device in the UniFi interface (eg. 'Living Room TV', 'John's Laptop').
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="networkId")
    def network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the network this client should be associated with. This is particularly important when using VLANs or multiple networks.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "network_id", value)

    @_builtins.property
    @pulumi.getter
    def note(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional information about the client that you want to record (e.g., 'Company asset tag #12345', 'Guest device - expires 2024-03-01').
        """
        return pulumi.get(self, "note")

    @note.setter
    def note(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "note", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this user should be managed. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter(name="skipForgetOnDestroy")
    def skip_forget_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When false (default), the client will be 'forgotten' by the controller when this resource is destroyed. Set to true to keep the client's history in the controller after the resource is removed from Terraform.
        """
        return pulumi.get(self, "skip_forget_on_destroy")

    @skip_forget_on_destroy.setter
    def skip_forget_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_forget_on_destroy", value)

    @_builtins.property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the user group this client belongs to. User groups can be used to apply common settings and restrictions to multiple clients.
        """
        return pulumi.get(self, "user_group_id")

    @user_group_id.setter
    def user_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_group_id", value)


@pulumi.type_token("unifi:iam/user:User")
class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_existing: Optional[pulumi.Input[_builtins.bool]] = None,
                 blocked: Optional[pulumi.Input[_builtins.bool]] = None,
                 dev_id_override: Optional[pulumi.Input[_builtins.int]] = None,
                 fixed_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 local_dns_record: Optional[pulumi.Input[_builtins.str]] = None,
                 mac: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 note: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_forget_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `iam.User` resource manages network clients in the UniFi controller, which are identified by their unique MAC addresses.

        This resource allows you to manage:
          * Fixed IP assignments
          * User groups and network access
          * Network blocking and restrictions
          * Local DNS records

        Important Notes:
          * Users are automatically created in the controller when devices connect to the network
          * By default, this resource can take over management of existing users (controlled by `allow_existing`)
          * Users can be 'forgotten' on destroy (controlled by `skip_forget_on_destroy`)

        This resource is particularly useful for:
          * Managing static IP assignments
          * Implementing access control
          * Setting up local DNS records
          * Organizing devices into user groups

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        test = unifi.iam.User("test",
            mac="01:23:45:67:89:AB",
            name="some client",
            note="my note",
            fixed_ip="10.0.0.50",
            network_id=my_vlan["id"])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allow_existing: Allow this resource to take over management of an existing user in the UniFi controller. When true:
                 * The resource can manage users that were automatically created when devices connected
                 * Existing settings will be overwritten with the values specified in this resource
                 * If false, attempting to manage an existing user will result in an error
               
               Use with caution as it can modify settings for devices already connected to your network.
        :param pulumi.Input[_builtins.bool] blocked: When true, this client will be blocked from accessing the network. Useful for temporarily or permanently restricting network access for specific devices.
        :param pulumi.Input[_builtins.int] dev_id_override: Override the device fingerprint.
        :param pulumi.Input[_builtins.str] fixed_ip: A static IPv4 address to assign to this client. Ensure this IP is within the client's network range and not already assigned to another device.
        :param pulumi.Input[_builtins.str] local_dns_record: A local DNS hostname for this client. When set, other devices on the network can resolve this name to the client's IP address (e.g., 'printer.local', 'nas.home.arpa'). Such DNS record is automatically added to controller's DNS records.
        :param pulumi.Input[_builtins.str] mac: The MAC address of the device/client. This is used as the unique identifier and cannot be changed after creation. Must be a valid MAC address format (e.g., '00:11:22:33:44:55'). MAC addresses are case-insensitive.
        :param pulumi.Input[_builtins.str] name: A friendly name for the device/client. This helps identify the device in the UniFi interface (eg. 'Living Room TV', 'John's Laptop').
        :param pulumi.Input[_builtins.str] network_id: The ID of the network this client should be associated with. This is particularly important when using VLANs or multiple networks.
        :param pulumi.Input[_builtins.str] note: Additional information about the client that you want to record (e.g., 'Company asset tag #12345', 'Guest device - expires 2024-03-01').
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this user should be managed. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.bool] skip_forget_on_destroy: When false (default), the client will be 'forgotten' by the controller when this resource is destroyed. Set to true to keep the client's history in the controller after the resource is removed from Terraform.
        :param pulumi.Input[_builtins.str] user_group_id: The ID of the user group this client belongs to. User groups can be used to apply common settings and restrictions to multiple clients.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `iam.User` resource manages network clients in the UniFi controller, which are identified by their unique MAC addresses.

        This resource allows you to manage:
          * Fixed IP assignments
          * User groups and network access
          * Network blocking and restrictions
          * Local DNS records

        Important Notes:
          * Users are automatically created in the controller when devices connect to the network
          * By default, this resource can take over management of existing users (controlled by `allow_existing`)
          * Users can be 'forgotten' on destroy (controlled by `skip_forget_on_destroy`)

        This resource is particularly useful for:
          * Managing static IP assignments
          * Implementing access control
          * Setting up local DNS records
          * Organizing devices into user groups

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        test = unifi.iam.User("test",
            mac="01:23:45:67:89:AB",
            name="some client",
            note="my note",
            fixed_ip="10.0.0.50",
            network_id=my_vlan["id"])
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_existing: Optional[pulumi.Input[_builtins.bool]] = None,
                 blocked: Optional[pulumi.Input[_builtins.bool]] = None,
                 dev_id_override: Optional[pulumi.Input[_builtins.int]] = None,
                 fixed_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 local_dns_record: Optional[pulumi.Input[_builtins.str]] = None,
                 mac: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 note: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_forget_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 user_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            __props__.__dict__["allow_existing"] = allow_existing
            __props__.__dict__["blocked"] = blocked
            __props__.__dict__["dev_id_override"] = dev_id_override
            __props__.__dict__["fixed_ip"] = fixed_ip
            __props__.__dict__["local_dns_record"] = local_dns_record
            if mac is None and not opts.urn:
                raise TypeError("Missing required property 'mac'")
            __props__.__dict__["mac"] = mac
            __props__.__dict__["name"] = name
            __props__.__dict__["network_id"] = network_id
            __props__.__dict__["note"] = note
            __props__.__dict__["site"] = site
            __props__.__dict__["skip_forget_on_destroy"] = skip_forget_on_destroy
            __props__.__dict__["user_group_id"] = user_group_id
            __props__.__dict__["hostname"] = None
            __props__.__dict__["ip"] = None
        super(User, __self__).__init__(
            'unifi:iam/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_existing: Optional[pulumi.Input[_builtins.bool]] = None,
            blocked: Optional[pulumi.Input[_builtins.bool]] = None,
            dev_id_override: Optional[pulumi.Input[_builtins.int]] = None,
            fixed_ip: Optional[pulumi.Input[_builtins.str]] = None,
            hostname: Optional[pulumi.Input[_builtins.str]] = None,
            ip: Optional[pulumi.Input[_builtins.str]] = None,
            local_dns_record: Optional[pulumi.Input[_builtins.str]] = None,
            mac: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            network_id: Optional[pulumi.Input[_builtins.str]] = None,
            note: Optional[pulumi.Input[_builtins.str]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None,
            skip_forget_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
            user_group_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] allow_existing: Allow this resource to take over management of an existing user in the UniFi controller. When true:
                 * The resource can manage users that were automatically created when devices connected
                 * Existing settings will be overwritten with the values specified in this resource
                 * If false, attempting to manage an existing user will result in an error
               
               Use with caution as it can modify settings for devices already connected to your network.
        :param pulumi.Input[_builtins.bool] blocked: When true, this client will be blocked from accessing the network. Useful for temporarily or permanently restricting network access for specific devices.
        :param pulumi.Input[_builtins.int] dev_id_override: Override the device fingerprint.
        :param pulumi.Input[_builtins.str] fixed_ip: A static IPv4 address to assign to this client. Ensure this IP is within the client's network range and not already assigned to another device.
        :param pulumi.Input[_builtins.str] hostname: The hostname of the user.
        :param pulumi.Input[_builtins.str] ip: The IP address of the user.
        :param pulumi.Input[_builtins.str] local_dns_record: A local DNS hostname for this client. When set, other devices on the network can resolve this name to the client's IP address (e.g., 'printer.local', 'nas.home.arpa'). Such DNS record is automatically added to controller's DNS records.
        :param pulumi.Input[_builtins.str] mac: The MAC address of the device/client. This is used as the unique identifier and cannot be changed after creation. Must be a valid MAC address format (e.g., '00:11:22:33:44:55'). MAC addresses are case-insensitive.
        :param pulumi.Input[_builtins.str] name: A friendly name for the device/client. This helps identify the device in the UniFi interface (eg. 'Living Room TV', 'John's Laptop').
        :param pulumi.Input[_builtins.str] network_id: The ID of the network this client should be associated with. This is particularly important when using VLANs or multiple networks.
        :param pulumi.Input[_builtins.str] note: Additional information about the client that you want to record (e.g., 'Company asset tag #12345', 'Guest device - expires 2024-03-01').
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this user should be managed. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.bool] skip_forget_on_destroy: When false (default), the client will be 'forgotten' by the controller when this resource is destroyed. Set to true to keep the client's history in the controller after the resource is removed from Terraform.
        :param pulumi.Input[_builtins.str] user_group_id: The ID of the user group this client belongs to. User groups can be used to apply common settings and restrictions to multiple clients.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["allow_existing"] = allow_existing
        __props__.__dict__["blocked"] = blocked
        __props__.__dict__["dev_id_override"] = dev_id_override
        __props__.__dict__["fixed_ip"] = fixed_ip
        __props__.__dict__["hostname"] = hostname
        __props__.__dict__["ip"] = ip
        __props__.__dict__["local_dns_record"] = local_dns_record
        __props__.__dict__["mac"] = mac
        __props__.__dict__["name"] = name
        __props__.__dict__["network_id"] = network_id
        __props__.__dict__["note"] = note
        __props__.__dict__["site"] = site
        __props__.__dict__["skip_forget_on_destroy"] = skip_forget_on_destroy
        __props__.__dict__["user_group_id"] = user_group_id
        return User(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="allowExisting")
    def allow_existing(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Allow this resource to take over management of an existing user in the UniFi controller. When true:
          * The resource can manage users that were automatically created when devices connected
          * Existing settings will be overwritten with the values specified in this resource
          * If false, attempting to manage an existing user will result in an error

        Use with caution as it can modify settings for devices already connected to your network.
        """
        return pulumi.get(self, "allow_existing")

    @_builtins.property
    @pulumi.getter
    def blocked(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        When true, this client will be blocked from accessing the network. Useful for temporarily or permanently restricting network access for specific devices.
        """
        return pulumi.get(self, "blocked")

    @_builtins.property
    @pulumi.getter(name="devIdOverride")
    def dev_id_override(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Override the device fingerprint.
        """
        return pulumi.get(self, "dev_id_override")

    @_builtins.property
    @pulumi.getter(name="fixedIp")
    def fixed_ip(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A static IPv4 address to assign to this client. Ensure this IP is within the client's network range and not already assigned to another device.
        """
        return pulumi.get(self, "fixed_ip")

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> pulumi.Output[_builtins.str]:
        """
        The hostname of the user.
        """
        return pulumi.get(self, "hostname")

    @_builtins.property
    @pulumi.getter
    def ip(self) -> pulumi.Output[_builtins.str]:
        """
        The IP address of the user.
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter(name="localDnsRecord")
    def local_dns_record(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A local DNS hostname for this client. When set, other devices on the network can resolve this name to the client's IP address (e.g., 'printer.local', 'nas.home.arpa'). Such DNS record is automatically added to controller's DNS records.
        """
        return pulumi.get(self, "local_dns_record")

    @_builtins.property
    @pulumi.getter
    def mac(self) -> pulumi.Output[_builtins.str]:
        """
        The MAC address of the device/client. This is used as the unique identifier and cannot be changed after creation. Must be a valid MAC address format (e.g., '00:11:22:33:44:55'). MAC addresses are case-insensitive.
        """
        return pulumi.get(self, "mac")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A friendly name for the device/client. This helps identify the device in the UniFi interface (eg. 'Living Room TV', 'John's Laptop').
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The ID of the network this client should be associated with. This is particularly important when using VLANs or multiple networks.
        """
        return pulumi.get(self, "network_id")

    @_builtins.property
    @pulumi.getter
    def note(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Additional information about the client that you want to record (e.g., 'Company asset tag #12345', 'Guest device - expires 2024-03-01').
        """
        return pulumi.get(self, "note")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where this user should be managed. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @_builtins.property
    @pulumi.getter(name="skipForgetOnDestroy")
    def skip_forget_on_destroy(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        When false (default), the client will be 'forgotten' by the controller when this resource is destroyed. Set to true to keep the client's history in the controller after the resource is removed from Terraform.
        """
        return pulumi.get(self, "skip_forget_on_destroy")

    @_builtins.property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The ID of the user group this client belongs to. User groups can be used to apply common settings and restrictions to multiple clients.
        """
        return pulumi.get(self, "user_group_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RsyslogdArgs', 'Rsyslogd']

@pulumi.input_type
class RsyslogdArgs:
    def __init__(__self__, *,
                 enabled: pulumi.Input[_builtins.bool],
                 contents: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 debug: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 log_all_contents: Optional[pulumi.Input[_builtins.bool]] = None,
                 netconsole_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 netconsole_host: Optional[pulumi.Input[_builtins.str]] = None,
                 netconsole_port: Optional[pulumi.Input[_builtins.int]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 this_controller: Optional[pulumi.Input[_builtins.bool]] = None,
                 this_controller_encrypted_only: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a Rsyslogd resource.
        :param pulumi.Input[_builtins.bool] enabled: Whether remote syslog is enabled.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] contents: List of log types to include in the remote syslog. Valid values: device, client, firewall*default*policy, triggers, updates, admin*activity, critical, security*detections, vpn.
        :param pulumi.Input[_builtins.bool] debug: Whether debug logging is enabled.
        :param pulumi.Input[_builtins.str] ip: IP address of the remote syslog server.
        :param pulumi.Input[_builtins.bool] log_all_contents: Whether to log all content types.
        :param pulumi.Input[_builtins.bool] netconsole_enabled: Whether netconsole logging is enabled.
        :param pulumi.Input[_builtins.str] netconsole_host: Hostname or IP address of the netconsole server.
        :param pulumi.Input[_builtins.int] netconsole_port: Port number for the netconsole server. Valid values: 1-65535.
        :param pulumi.Input[_builtins.int] port: Port number for the remote syslog server. Valid values: 1-65535.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.bool] this_controller: Whether to use this controller as the syslog server.
        :param pulumi.Input[_builtins.bool] this_controller_encrypted_only: Whether to only use encrypted connections to this controller for syslog.
        """
        pulumi.set(__self__, "enabled", enabled)
        if contents is not None:
            pulumi.set(__self__, "contents", contents)
        if debug is not None:
            pulumi.set(__self__, "debug", debug)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if log_all_contents is not None:
            pulumi.set(__self__, "log_all_contents", log_all_contents)
        if netconsole_enabled is not None:
            pulumi.set(__self__, "netconsole_enabled", netconsole_enabled)
        if netconsole_host is not None:
            pulumi.set(__self__, "netconsole_host", netconsole_host)
        if netconsole_port is not None:
            pulumi.set(__self__, "netconsole_port", netconsole_port)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if this_controller is not None:
            pulumi.set(__self__, "this_controller", this_controller)
        if this_controller_encrypted_only is not None:
            pulumi.set(__self__, "this_controller_encrypted_only", this_controller_encrypted_only)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[_builtins.bool]:
        """
        Whether remote syslog is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def contents(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of log types to include in the remote syslog. Valid values: device, client, firewall*default*policy, triggers, updates, admin*activity, critical, security*detections, vpn.
        """
        return pulumi.get(self, "contents")

    @contents.setter
    def contents(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "contents", value)

    @_builtins.property
    @pulumi.getter
    def debug(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether debug logging is enabled.
        """
        return pulumi.get(self, "debug")

    @debug.setter
    def debug(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "debug", value)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IP address of the remote syslog server.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter(name="logAllContents")
    def log_all_contents(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to log all content types.
        """
        return pulumi.get(self, "log_all_contents")

    @log_all_contents.setter
    def log_all_contents(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "log_all_contents", value)

    @_builtins.property
    @pulumi.getter(name="netconsoleEnabled")
    def netconsole_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether netconsole logging is enabled.
        """
        return pulumi.get(self, "netconsole_enabled")

    @netconsole_enabled.setter
    def netconsole_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "netconsole_enabled", value)

    @_builtins.property
    @pulumi.getter(name="netconsoleHost")
    def netconsole_host(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Hostname or IP address of the netconsole server.
        """
        return pulumi.get(self, "netconsole_host")

    @netconsole_host.setter
    def netconsole_host(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "netconsole_host", value)

    @_builtins.property
    @pulumi.getter(name="netconsolePort")
    def netconsole_port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Port number for the netconsole server. Valid values: 1-65535.
        """
        return pulumi.get(self, "netconsole_port")

    @netconsole_port.setter
    def netconsole_port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "netconsole_port", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Port number for the remote syslog server. Valid values: 1-65535.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter(name="thisController")
    def this_controller(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to use this controller as the syslog server.
        """
        return pulumi.get(self, "this_controller")

    @this_controller.setter
    def this_controller(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "this_controller", value)

    @_builtins.property
    @pulumi.getter(name="thisControllerEncryptedOnly")
    def this_controller_encrypted_only(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to only use encrypted connections to this controller for syslog.
        """
        return pulumi.get(self, "this_controller_encrypted_only")

    @this_controller_encrypted_only.setter
    def this_controller_encrypted_only(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "this_controller_encrypted_only", value)


@pulumi.input_type
class _RsyslogdState:
    def __init__(__self__, *,
                 contents: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 debug: Optional[pulumi.Input[_builtins.bool]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 log_all_contents: Optional[pulumi.Input[_builtins.bool]] = None,
                 netconsole_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 netconsole_host: Optional[pulumi.Input[_builtins.str]] = None,
                 netconsole_port: Optional[pulumi.Input[_builtins.int]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 this_controller: Optional[pulumi.Input[_builtins.bool]] = None,
                 this_controller_encrypted_only: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering Rsyslogd resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] contents: List of log types to include in the remote syslog. Valid values: device, client, firewall*default*policy, triggers, updates, admin*activity, critical, security*detections, vpn.
        :param pulumi.Input[_builtins.bool] debug: Whether debug logging is enabled.
        :param pulumi.Input[_builtins.bool] enabled: Whether remote syslog is enabled.
        :param pulumi.Input[_builtins.str] ip: IP address of the remote syslog server.
        :param pulumi.Input[_builtins.bool] log_all_contents: Whether to log all content types.
        :param pulumi.Input[_builtins.bool] netconsole_enabled: Whether netconsole logging is enabled.
        :param pulumi.Input[_builtins.str] netconsole_host: Hostname or IP address of the netconsole server.
        :param pulumi.Input[_builtins.int] netconsole_port: Port number for the netconsole server. Valid values: 1-65535.
        :param pulumi.Input[_builtins.int] port: Port number for the remote syslog server. Valid values: 1-65535.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.bool] this_controller: Whether to use this controller as the syslog server.
        :param pulumi.Input[_builtins.bool] this_controller_encrypted_only: Whether to only use encrypted connections to this controller for syslog.
        """
        if contents is not None:
            pulumi.set(__self__, "contents", contents)
        if debug is not None:
            pulumi.set(__self__, "debug", debug)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if log_all_contents is not None:
            pulumi.set(__self__, "log_all_contents", log_all_contents)
        if netconsole_enabled is not None:
            pulumi.set(__self__, "netconsole_enabled", netconsole_enabled)
        if netconsole_host is not None:
            pulumi.set(__self__, "netconsole_host", netconsole_host)
        if netconsole_port is not None:
            pulumi.set(__self__, "netconsole_port", netconsole_port)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if this_controller is not None:
            pulumi.set(__self__, "this_controller", this_controller)
        if this_controller_encrypted_only is not None:
            pulumi.set(__self__, "this_controller_encrypted_only", this_controller_encrypted_only)

    @_builtins.property
    @pulumi.getter
    def contents(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of log types to include in the remote syslog. Valid values: device, client, firewall*default*policy, triggers, updates, admin*activity, critical, security*detections, vpn.
        """
        return pulumi.get(self, "contents")

    @contents.setter
    def contents(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "contents", value)

    @_builtins.property
    @pulumi.getter
    def debug(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether debug logging is enabled.
        """
        return pulumi.get(self, "debug")

    @debug.setter
    def debug(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "debug", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether remote syslog is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IP address of the remote syslog server.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter(name="logAllContents")
    def log_all_contents(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to log all content types.
        """
        return pulumi.get(self, "log_all_contents")

    @log_all_contents.setter
    def log_all_contents(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "log_all_contents", value)

    @_builtins.property
    @pulumi.getter(name="netconsoleEnabled")
    def netconsole_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether netconsole logging is enabled.
        """
        return pulumi.get(self, "netconsole_enabled")

    @netconsole_enabled.setter
    def netconsole_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "netconsole_enabled", value)

    @_builtins.property
    @pulumi.getter(name="netconsoleHost")
    def netconsole_host(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Hostname or IP address of the netconsole server.
        """
        return pulumi.get(self, "netconsole_host")

    @netconsole_host.setter
    def netconsole_host(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "netconsole_host", value)

    @_builtins.property
    @pulumi.getter(name="netconsolePort")
    def netconsole_port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Port number for the netconsole server. Valid values: 1-65535.
        """
        return pulumi.get(self, "netconsole_port")

    @netconsole_port.setter
    def netconsole_port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "netconsole_port", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Port number for the remote syslog server. Valid values: 1-65535.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter(name="thisController")
    def this_controller(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to use this controller as the syslog server.
        """
        return pulumi.get(self, "this_controller")

    @this_controller.setter
    def this_controller(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "this_controller", value)

    @_builtins.property
    @pulumi.getter(name="thisControllerEncryptedOnly")
    def this_controller_encrypted_only(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to only use encrypted connections to this controller for syslog.
        """
        return pulumi.get(self, "this_controller_encrypted_only")

    @this_controller_encrypted_only.setter
    def this_controller_encrypted_only(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "this_controller_encrypted_only", value)


@pulumi.type_token("unifi:setting/rsyslogd:Rsyslogd")
class Rsyslogd(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 contents: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 debug: Optional[pulumi.Input[_builtins.bool]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 log_all_contents: Optional[pulumi.Input[_builtins.bool]] = None,
                 netconsole_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 netconsole_host: Optional[pulumi.Input[_builtins.str]] = None,
                 netconsole_port: Optional[pulumi.Input[_builtins.int]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 this_controller: Optional[pulumi.Input[_builtins.bool]] = None,
                 this_controller_encrypted_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Manages Remote Syslog (rsyslogd) settings for UniFi devices. Controller version 8.5 or later is required.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        example = unifi.setting.Rsyslogd("example",
            enabled=True,
            ip="192.168.1.200",
            port=514,
            contents=[
                "device",
                "client",
                "admin_activity",
            ],
            debug=True,
            netconsole_enabled=True,
            netconsole_host="192.168.1.150",
            netconsole_port=1514)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] contents: List of log types to include in the remote syslog. Valid values: device, client, firewall*default*policy, triggers, updates, admin*activity, critical, security*detections, vpn.
        :param pulumi.Input[_builtins.bool] debug: Whether debug logging is enabled.
        :param pulumi.Input[_builtins.bool] enabled: Whether remote syslog is enabled.
        :param pulumi.Input[_builtins.str] ip: IP address of the remote syslog server.
        :param pulumi.Input[_builtins.bool] log_all_contents: Whether to log all content types.
        :param pulumi.Input[_builtins.bool] netconsole_enabled: Whether netconsole logging is enabled.
        :param pulumi.Input[_builtins.str] netconsole_host: Hostname or IP address of the netconsole server.
        :param pulumi.Input[_builtins.int] netconsole_port: Port number for the netconsole server. Valid values: 1-65535.
        :param pulumi.Input[_builtins.int] port: Port number for the remote syslog server. Valid values: 1-65535.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.bool] this_controller: Whether to use this controller as the syslog server.
        :param pulumi.Input[_builtins.bool] this_controller_encrypted_only: Whether to only use encrypted connections to this controller for syslog.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RsyslogdArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Remote Syslog (rsyslogd) settings for UniFi devices. Controller version 8.5 or later is required.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        example = unifi.setting.Rsyslogd("example",
            enabled=True,
            ip="192.168.1.200",
            port=514,
            contents=[
                "device",
                "client",
                "admin_activity",
            ],
            debug=True,
            netconsole_enabled=True,
            netconsole_host="192.168.1.150",
            netconsole_port=1514)
        ```

        :param str resource_name: The name of the resource.
        :param RsyslogdArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RsyslogdArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 contents: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 debug: Optional[pulumi.Input[_builtins.bool]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 log_all_contents: Optional[pulumi.Input[_builtins.bool]] = None,
                 netconsole_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 netconsole_host: Optional[pulumi.Input[_builtins.str]] = None,
                 netconsole_port: Optional[pulumi.Input[_builtins.int]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 this_controller: Optional[pulumi.Input[_builtins.bool]] = None,
                 this_controller_encrypted_only: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RsyslogdArgs.__new__(RsyslogdArgs)

            __props__.__dict__["contents"] = contents
            __props__.__dict__["debug"] = debug
            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["ip"] = ip
            __props__.__dict__["log_all_contents"] = log_all_contents
            __props__.__dict__["netconsole_enabled"] = netconsole_enabled
            __props__.__dict__["netconsole_host"] = netconsole_host
            __props__.__dict__["netconsole_port"] = netconsole_port
            __props__.__dict__["port"] = port
            __props__.__dict__["site"] = site
            __props__.__dict__["this_controller"] = this_controller
            __props__.__dict__["this_controller_encrypted_only"] = this_controller_encrypted_only
        super(Rsyslogd, __self__).__init__(
            'unifi:setting/rsyslogd:Rsyslogd',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            contents: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            debug: Optional[pulumi.Input[_builtins.bool]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            ip: Optional[pulumi.Input[_builtins.str]] = None,
            log_all_contents: Optional[pulumi.Input[_builtins.bool]] = None,
            netconsole_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            netconsole_host: Optional[pulumi.Input[_builtins.str]] = None,
            netconsole_port: Optional[pulumi.Input[_builtins.int]] = None,
            port: Optional[pulumi.Input[_builtins.int]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None,
            this_controller: Optional[pulumi.Input[_builtins.bool]] = None,
            this_controller_encrypted_only: Optional[pulumi.Input[_builtins.bool]] = None) -> 'Rsyslogd':
        """
        Get an existing Rsyslogd resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] contents: List of log types to include in the remote syslog. Valid values: device, client, firewall*default*policy, triggers, updates, admin*activity, critical, security*detections, vpn.
        :param pulumi.Input[_builtins.bool] debug: Whether debug logging is enabled.
        :param pulumi.Input[_builtins.bool] enabled: Whether remote syslog is enabled.
        :param pulumi.Input[_builtins.str] ip: IP address of the remote syslog server.
        :param pulumi.Input[_builtins.bool] log_all_contents: Whether to log all content types.
        :param pulumi.Input[_builtins.bool] netconsole_enabled: Whether netconsole logging is enabled.
        :param pulumi.Input[_builtins.str] netconsole_host: Hostname or IP address of the netconsole server.
        :param pulumi.Input[_builtins.int] netconsole_port: Port number for the netconsole server. Valid values: 1-65535.
        :param pulumi.Input[_builtins.int] port: Port number for the remote syslog server. Valid values: 1-65535.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.bool] this_controller: Whether to use this controller as the syslog server.
        :param pulumi.Input[_builtins.bool] this_controller_encrypted_only: Whether to only use encrypted connections to this controller for syslog.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RsyslogdState.__new__(_RsyslogdState)

        __props__.__dict__["contents"] = contents
        __props__.__dict__["debug"] = debug
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["ip"] = ip
        __props__.__dict__["log_all_contents"] = log_all_contents
        __props__.__dict__["netconsole_enabled"] = netconsole_enabled
        __props__.__dict__["netconsole_host"] = netconsole_host
        __props__.__dict__["netconsole_port"] = netconsole_port
        __props__.__dict__["port"] = port
        __props__.__dict__["site"] = site
        __props__.__dict__["this_controller"] = this_controller
        __props__.__dict__["this_controller_encrypted_only"] = this_controller_encrypted_only
        return Rsyslogd(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def contents(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of log types to include in the remote syslog. Valid values: device, client, firewall*default*policy, triggers, updates, admin*activity, critical, security*detections, vpn.
        """
        return pulumi.get(self, "contents")

    @_builtins.property
    @pulumi.getter
    def debug(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether debug logging is enabled.
        """
        return pulumi.get(self, "debug")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether remote syslog is enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def ip(self) -> pulumi.Output[_builtins.str]:
        """
        IP address of the remote syslog server.
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter(name="logAllContents")
    def log_all_contents(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to log all content types.
        """
        return pulumi.get(self, "log_all_contents")

    @_builtins.property
    @pulumi.getter(name="netconsoleEnabled")
    def netconsole_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether netconsole logging is enabled.
        """
        return pulumi.get(self, "netconsole_enabled")

    @_builtins.property
    @pulumi.getter(name="netconsoleHost")
    def netconsole_host(self) -> pulumi.Output[_builtins.str]:
        """
        Hostname or IP address of the netconsole server.
        """
        return pulumi.get(self, "netconsole_host")

    @_builtins.property
    @pulumi.getter(name="netconsolePort")
    def netconsole_port(self) -> pulumi.Output[_builtins.int]:
        """
        Port number for the netconsole server. Valid values: 1-65535.
        """
        return pulumi.get(self, "netconsole_port")

    @_builtins.property
    @pulumi.getter
    def port(self) -> pulumi.Output[_builtins.int]:
        """
        Port number for the remote syslog server. Valid values: 1-65535.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @_builtins.property
    @pulumi.getter(name="thisController")
    def this_controller(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to use this controller as the syslog server.
        """
        return pulumi.get(self, "this_controller")

    @_builtins.property
    @pulumi.getter(name="thisControllerEncryptedOnly")
    def this_controller_encrypted_only(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to only use encrypted connections to this controller for syslog.
        """
        return pulumi.get(self, "this_controller_encrypted_only")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'DevicePortOverrideArgs',
    'DevicePortOverrideArgsDict',
    'RadiusProfileAcctServerArgs',
    'RadiusProfileAcctServerArgsDict',
    'RadiusProfileAuthServerArgs',
    'RadiusProfileAuthServerArgsDict',
    'WlanScheduleArgs',
    'WlanScheduleArgsDict',
]

class DevicePortOverrideArgsDict(TypedDict):
    number: pulumi.Input[_builtins.int]
    """
    The physical port number on the switch to configure.
    """
    aggregate_num_ports: NotRequired[pulumi.Input[_builtins.int]]
    """
    The number of ports to include in a link aggregation group (LAG). Valid range: 2-8 ports. Used when:
    * Creating switch-to-switch uplinks for increased bandwidth
    * Setting up high-availability connections
    * Connecting to servers requiring more bandwidth
    Note: All ports in the LAG must be sequential and have matching configurations.
    """
    name: NotRequired[pulumi.Input[_builtins.str]]
    """
    A friendly name for the port that will be displayed in the UniFi controller UI. Examples:
      * 'Uplink to Core Switch'
      * 'Conference Room AP'
      * 'Server LACP Group 1'
      * 'VoIP Phone Port'
    """
    op_mode: NotRequired[pulumi.Input[_builtins.str]]
    """
    The operating mode of the port. Valid values are:
      * `switch` - Normal switching mode (default)
        - Standard port operation for connecting devices
        - Supports VLANs and all standard switching features
      * `mirror` - Port mirroring for traffic analysis
        - Copies traffic from other ports for monitoring
        - Useful for network troubleshooting and security
      * `aggregate` - Link aggregation/bonding mode
        - Combines multiple ports for increased bandwidth
        - Used for switch uplinks or high-bandwidth servers
    """
    poe_mode: NotRequired[pulumi.Input[_builtins.str]]
    """
    The Power over Ethernet (PoE) mode for the port. Valid values are:
    * `auto` - Automatically detect and power PoE devices (recommended)
      - Provides power based on device negotiation
      - Safest option for most PoE devices
    * `pasv24` - Passive 24V PoE
      - For older UniFi devices requiring passive 24V
      - Use with caution to avoid damage
    * `passthrough` - PoE passthrough mode
      - For daisy-chaining PoE devices
      - Available on select UniFi switches
    * `off` - Disable PoE on the port
      - For non-PoE devices
      - To prevent unwanted power delivery
    """
    port_profile_id: NotRequired[pulumi.Input[_builtins.str]]
    """
    The ID of a pre-configured port profile to apply to this port. Port profiles define settings like VLANs, PoE, and other port-specific configurations.
    """

@pulumi.input_type
class DevicePortOverrideArgs:
    def __init__(__self__, *,
                 number: pulumi.Input[_builtins.int],
                 aggregate_num_ports: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 op_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 poe_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 port_profile_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.int] number: The physical port number on the switch to configure.
        :param pulumi.Input[_builtins.int] aggregate_num_ports: The number of ports to include in a link aggregation group (LAG). Valid range: 2-8 ports. Used when:
               * Creating switch-to-switch uplinks for increased bandwidth
               * Setting up high-availability connections
               * Connecting to servers requiring more bandwidth
               Note: All ports in the LAG must be sequential and have matching configurations.
        :param pulumi.Input[_builtins.str] name: A friendly name for the port that will be displayed in the UniFi controller UI. Examples:
                 * 'Uplink to Core Switch'
                 * 'Conference Room AP'
                 * 'Server LACP Group 1'
                 * 'VoIP Phone Port'
        :param pulumi.Input[_builtins.str] op_mode: The operating mode of the port. Valid values are:
                 * `switch` - Normal switching mode (default)
                   - Standard port operation for connecting devices
                   - Supports VLANs and all standard switching features
                 * `mirror` - Port mirroring for traffic analysis
                   - Copies traffic from other ports for monitoring
                   - Useful for network troubleshooting and security
                 * `aggregate` - Link aggregation/bonding mode
                   - Combines multiple ports for increased bandwidth
                   - Used for switch uplinks or high-bandwidth servers
        :param pulumi.Input[_builtins.str] poe_mode: The Power over Ethernet (PoE) mode for the port. Valid values are:
               * `auto` - Automatically detect and power PoE devices (recommended)
                 - Provides power based on device negotiation
                 - Safest option for most PoE devices
               * `pasv24` - Passive 24V PoE
                 - For older UniFi devices requiring passive 24V
                 - Use with caution to avoid damage
               * `passthrough` - PoE passthrough mode
                 - For daisy-chaining PoE devices
                 - Available on select UniFi switches
               * `off` - Disable PoE on the port
                 - For non-PoE devices
                 - To prevent unwanted power delivery
        :param pulumi.Input[_builtins.str] port_profile_id: The ID of a pre-configured port profile to apply to this port. Port profiles define settings like VLANs, PoE, and other port-specific configurations.
        """
        pulumi.set(__self__, "number", number)
        if aggregate_num_ports is not None:
            pulumi.set(__self__, "aggregate_num_ports", aggregate_num_ports)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if op_mode is not None:
            pulumi.set(__self__, "op_mode", op_mode)
        if poe_mode is not None:
            pulumi.set(__self__, "poe_mode", poe_mode)
        if port_profile_id is not None:
            pulumi.set(__self__, "port_profile_id", port_profile_id)

    @_builtins.property
    @pulumi.getter
    def number(self) -> pulumi.Input[_builtins.int]:
        """
        The physical port number on the switch to configure.
        """
        return pulumi.get(self, "number")

    @number.setter
    def number(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "number", value)

    @_builtins.property
    @pulumi.getter(name="aggregateNumPorts")
    def aggregate_num_ports(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of ports to include in a link aggregation group (LAG). Valid range: 2-8 ports. Used when:
        * Creating switch-to-switch uplinks for increased bandwidth
        * Setting up high-availability connections
        * Connecting to servers requiring more bandwidth
        Note: All ports in the LAG must be sequential and have matching configurations.
        """
        return pulumi.get(self, "aggregate_num_ports")

    @aggregate_num_ports.setter
    def aggregate_num_ports(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "aggregate_num_ports", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A friendly name for the port that will be displayed in the UniFi controller UI. Examples:
          * 'Uplink to Core Switch'
          * 'Conference Room AP'
          * 'Server LACP Group 1'
          * 'VoIP Phone Port'
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="opMode")
    def op_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The operating mode of the port. Valid values are:
          * `switch` - Normal switching mode (default)
            - Standard port operation for connecting devices
            - Supports VLANs and all standard switching features
          * `mirror` - Port mirroring for traffic analysis
            - Copies traffic from other ports for monitoring
            - Useful for network troubleshooting and security
          * `aggregate` - Link aggregation/bonding mode
            - Combines multiple ports for increased bandwidth
            - Used for switch uplinks or high-bandwidth servers
        """
        return pulumi.get(self, "op_mode")

    @op_mode.setter
    def op_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "op_mode", value)

    @_builtins.property
    @pulumi.getter(name="poeMode")
    def poe_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Power over Ethernet (PoE) mode for the port. Valid values are:
        * `auto` - Automatically detect and power PoE devices (recommended)
          - Provides power based on device negotiation
          - Safest option for most PoE devices
        * `pasv24` - Passive 24V PoE
          - For older UniFi devices requiring passive 24V
          - Use with caution to avoid damage
        * `passthrough` - PoE passthrough mode
          - For daisy-chaining PoE devices
          - Available on select UniFi switches
        * `off` - Disable PoE on the port
          - For non-PoE devices
          - To prevent unwanted power delivery
        """
        return pulumi.get(self, "poe_mode")

    @poe_mode.setter
    def poe_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "poe_mode", value)

    @_builtins.property
    @pulumi.getter(name="portProfileId")
    def port_profile_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of a pre-configured port profile to apply to this port. Port profiles define settings like VLANs, PoE, and other port-specific configurations.
        """
        return pulumi.get(self, "port_profile_id")

    @port_profile_id.setter
    def port_profile_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "port_profile_id", value)


class RadiusProfileAcctServerArgsDict(TypedDict):
    ip: pulumi.Input[_builtins.str]
    """
    The IPv4 address of the RADIUS accounting server (e.g., '192.168.1.100'). Must be reachable from your UniFi network.
    """
    xsecret: pulumi.Input[_builtins.str]
    """
    The shared secret key used to secure communication between the UniFi controller and the RADIUS server. This must match the secret configured on your RADIUS server.
    """
    port: NotRequired[pulumi.Input[_builtins.int]]
    """
    The UDP port number where the RADIUS accounting service is listening. The standard port is 1813, but this can be changed if needed to match your server configuration.
    """

@pulumi.input_type
class RadiusProfileAcctServerArgs:
    def __init__(__self__, *,
                 ip: pulumi.Input[_builtins.str],
                 xsecret: pulumi.Input[_builtins.str],
                 port: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.str] ip: The IPv4 address of the RADIUS accounting server (e.g., '192.168.1.100'). Must be reachable from your UniFi network.
        :param pulumi.Input[_builtins.str] xsecret: The shared secret key used to secure communication between the UniFi controller and the RADIUS server. This must match the secret configured on your RADIUS server.
        :param pulumi.Input[_builtins.int] port: The UDP port number where the RADIUS accounting service is listening. The standard port is 1813, but this can be changed if needed to match your server configuration.
        """
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "xsecret", xsecret)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> pulumi.Input[_builtins.str]:
        """
        The IPv4 address of the RADIUS accounting server (e.g., '192.168.1.100'). Must be reachable from your UniFi network.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter
    def xsecret(self) -> pulumi.Input[_builtins.str]:
        """
        The shared secret key used to secure communication between the UniFi controller and the RADIUS server. This must match the secret configured on your RADIUS server.
        """
        return pulumi.get(self, "xsecret")

    @xsecret.setter
    def xsecret(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "xsecret", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The UDP port number where the RADIUS accounting service is listening. The standard port is 1813, but this can be changed if needed to match your server configuration.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)


class RadiusProfileAuthServerArgsDict(TypedDict):
    ip: pulumi.Input[_builtins.str]
    """
    The IPv4 address of the RADIUS authentication server (e.g., '192.168.1.100'). Must be reachable from your UniFi network.
    """
    xsecret: pulumi.Input[_builtins.str]
    """
    The shared secret key used to secure communication between the UniFi controller and the RADIUS server. This must match the secret configured on your RADIUS server.
    """
    port: NotRequired[pulumi.Input[_builtins.int]]
    """
    The UDP port number where the RADIUS authentication service is listening. The standard port is 1812, but this can be changed if needed to match your server configuration.
    """

@pulumi.input_type
class RadiusProfileAuthServerArgs:
    def __init__(__self__, *,
                 ip: pulumi.Input[_builtins.str],
                 xsecret: pulumi.Input[_builtins.str],
                 port: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.str] ip: The IPv4 address of the RADIUS authentication server (e.g., '192.168.1.100'). Must be reachable from your UniFi network.
        :param pulumi.Input[_builtins.str] xsecret: The shared secret key used to secure communication between the UniFi controller and the RADIUS server. This must match the secret configured on your RADIUS server.
        :param pulumi.Input[_builtins.int] port: The UDP port number where the RADIUS authentication service is listening. The standard port is 1812, but this can be changed if needed to match your server configuration.
        """
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "xsecret", xsecret)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> pulumi.Input[_builtins.str]:
        """
        The IPv4 address of the RADIUS authentication server (e.g., '192.168.1.100'). Must be reachable from your UniFi network.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter
    def xsecret(self) -> pulumi.Input[_builtins.str]:
        """
        The shared secret key used to secure communication between the UniFi controller and the RADIUS server. This must match the secret configured on your RADIUS server.
        """
        return pulumi.get(self, "xsecret")

    @xsecret.setter
    def xsecret(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "xsecret", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The UDP port number where the RADIUS authentication service is listening. The standard port is 1812, but this can be changed if needed to match your server configuration.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)


class WlanScheduleArgsDict(TypedDict):
    day_of_week: pulumi.Input[_builtins.str]
    """
    Day of week. Valid values: `sun`, `mon`, `tue`, `wed`, `thu`, `fri`, `sat`.
    """
    duration: pulumi.Input[_builtins.int]
    """
    Duration in minutes that the network should remain active.
    """
    start_hour: pulumi.Input[_builtins.int]
    """
    Start hour in 24-hour format (0-23).
    """
    name: NotRequired[pulumi.Input[_builtins.str]]
    """
    Friendly name for this schedule block (e.g., 'Business Hours', 'Weekend Access').
    """
    start_minute: NotRequired[pulumi.Input[_builtins.int]]
    """
    Start minute (0-59).
    """

@pulumi.input_type
class WlanScheduleArgs:
    def __init__(__self__, *,
                 day_of_week: pulumi.Input[_builtins.str],
                 duration: pulumi.Input[_builtins.int],
                 start_hour: pulumi.Input[_builtins.int],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 start_minute: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.str] day_of_week: Day of week. Valid values: `sun`, `mon`, `tue`, `wed`, `thu`, `fri`, `sat`.
        :param pulumi.Input[_builtins.int] duration: Duration in minutes that the network should remain active.
        :param pulumi.Input[_builtins.int] start_hour: Start hour in 24-hour format (0-23).
        :param pulumi.Input[_builtins.str] name: Friendly name for this schedule block (e.g., 'Business Hours', 'Weekend Access').
        :param pulumi.Input[_builtins.int] start_minute: Start minute (0-59).
        """
        pulumi.set(__self__, "day_of_week", day_of_week)
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "start_hour", start_hour)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if start_minute is not None:
            pulumi.set(__self__, "start_minute", start_minute)

    @_builtins.property
    @pulumi.getter(name="dayOfWeek")
    def day_of_week(self) -> pulumi.Input[_builtins.str]:
        """
        Day of week. Valid values: `sun`, `mon`, `tue`, `wed`, `thu`, `fri`, `sat`.
        """
        return pulumi.get(self, "day_of_week")

    @day_of_week.setter
    def day_of_week(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "day_of_week", value)

    @_builtins.property
    @pulumi.getter
    def duration(self) -> pulumi.Input[_builtins.int]:
        """
        Duration in minutes that the network should remain active.
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "duration", value)

    @_builtins.property
    @pulumi.getter(name="startHour")
    def start_hour(self) -> pulumi.Input[_builtins.int]:
        """
        Start hour in 24-hour format (0-23).
        """
        return pulumi.get(self, "start_hour")

    @start_hour.setter
    def start_hour(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "start_hour", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Friendly name for this schedule block (e.g., 'Business Hours', 'Weekend Access').
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="startMinute")
    def start_minute(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Start minute (0-59).
        """
        return pulumi.get(self, "start_minute")

    @start_minute.setter
    def start_minute(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "start_minute", value)


